{% extends "vault/base.html" %}

{% load i18n static %}

{% block title %}Object Storage &rsaquo; {% trans "Account" %}{% endblock %}

{% block content_title %}{% trans "Account" %}{% endblock %}

{% block content_breadcrumb %}
<a href="#">Object Storage</a>
<span>{% trans "Account" %}</span>
{% endblock %}

{% block content %}
  <div class="card">
    <div class="card-body">
      <div>Account Name: {{ project_name }}</div>
      <div>Account ID: {{ project_id }}</div>
      <div>Account Domain ID: {{ account_domain_id }}</div>
      <br>
      <div>Used Space: {{ total_bytes|filesizeformat }}</div>
      <div>Containers: {{ total_containers }}</div>
      <div>Objects: {{ total_objects }}</div>
      <br>
      <div>Cloud: {% firstof cloud "No" %}</div>
    </div>
  </div>
{% endblock %}

{% block js_bottom %}
<script src="{% static 'vendor/js/vue.js' if debug else 'vendor/js/vue.min.js' %}"></script>
<script src="{% static 'vault/js/account.js' %}"></script>
{% endblock %}
