.box,
.box-table {
  position: relative;
  box-sizing: border-box;
  padding: 30px;
  background: white;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.2);
  border-radius: 4px;
  margin-bottom: 30px;
}

.box-table {
  box-sizing: border-box;
  padding: 0;
  border: 1px solid var(--line-context-color);
  box-shadow: none;
}
