{% extends "vault/base.html" %}

{% block title %}Storage - {{ project_name }}{% endblock %}

{% block content_title %}Object Storage{% endblock %}

{% block content_breadcrumb %}
  <a href="{% url 'containerview' project_name %}">Containers</a>
  <a class="u" href="{% url 'objectview' project=project_name container=container %}">{{ container }}</a>
  {% for prefix in prefixes %}
    <a href="{% url 'objectview' project=project_name container=container prefix=prefix.full_name %}">{{ prefix.display_name }}</a>
  {% endfor %}
  <span>Create Pseudofolder</span>
{% endblock %}

{% block content %}
  <form method="POST" class="form-box project-form">
    {% csrf_token %}
    <fieldset class="content">
      <div class="col-md-12">
        <div class="form-group">
            {{ form.foldername.label_tag }}
            {{ form.foldername }}
            {{ form.foldername.errors }}
            <br>
            <span class="help-block">
                Enter name of pseudofolder here.<br>
                Please note that you can not rename it afterwards.
            </span>
        </div>

      <div class="col-md-6">&nbsp;</div>
    </fieldset>

    <fieldset class="base">
      <div class="col-md-12">
        <button type="submit" class="btn btn-primary">Create</button>
      </div>
    </fieldset>
  </form>
</div>
{% endblock %}clear
