{% load i18n %}

{% if user.is_staff and user.is_superuser %}
  <div class="app-projectsandusers module">
    <table class="items-list table table-striped">
      <caption>{% trans 'Keystone' %}</caption>
      <tbody>
        <tr class="model-projectsandusers">
          <th scope="row">
            <a href="{% url 'projects' project_name %}">{% trans 'Projects' %}</a>
          </th>
          <td>
            <a href="{% url 'add_project' %}" class="addlink btn btn-sm btn-default">{% trans 'Add' %}</a>
          </td>
        </tr>
        <tr class="model-projectsandusers">
          <th scope="row">
            <a href="{% url 'admin_list_users' project_name %}">{% trans 'Users' %}</a>
          </th>
          <td>
            <a href="{% url 'admin_add_user' project_name %}" class="addlink btn btn-sm btn-default">{% trans 'Add' %}</a>
          </td>
        </tr>
      </tbody>
    </table>
  </div>
{% endif %}
