# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-12-03 22:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BackupContainer',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('container', models.CharField(max_length=255)),
                ('project_id', models.CharField(max_length=255)),
                ('project_name', models.CharField(max_length=255)),
                ('created_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'db_table': 'swift_backup_container',
            },
        ),
        migrations.AlterUniqueTogether(
            name='backupcontainer',
            unique_together=set([('container', 'project_id')]),
        ),
    ]
