/*!
 * bootstrap-fileinput v5.0.9
 * http://plugins.krajee.com/file-input
 *
 * Krajee RTL (Right To Left) default styling for bootstrap-fileinput.
 *
 * Author: Kartik Visweswaran
 * Copyright: 2014 - 2019, Kartik Visweswaran, Krajee.com
 *
 * Licensed under the BSD-3-Clause
 * https://github.com/kartik-v/bootstrap-fileinput/blob/master/LICENSE.md
 */
.kv-rtl .close, .kv-rtl .krajee-default .file-actions, .kv-rtl .krajee-default .file-other-error {
    float: left;
}
.kv-rtl .krajee-default.file-preview-frame, .kv-rtl .krajee-default .file-drag-handle, .kv-rtl .krajee-default .file-upload-indicator {
    float: right;
}
.kv-rtl .file-zoom-dialog, .kv-rtl .file-error-message pre, .kv-rtl .file-error-message ul {
    text-align: right;
}
.kv-rtl {
    direction: rtl;
}
.kv-rtl .floating-buttons {
    left: 10px;
    right: auto;
}
.kv-rtl .floating-buttons .btn-kv {
    margin-left: 0;
    margin-right: 3px;
}
.kv-rtl .file-caption-icon {
    left: auto;
    right: 8px;
}
.kv-rtl .file-drop-zone {
    margin: 12px 12px 12px 15px;
}
.kv-rtl .btn-prev {
    right: 1px;
    left: auto;
}
.kv-rtl .btn-next {
    left: 1px;
    right: auto;
}
.kv-rtl .pull-right, .kv-rtl .float-right {
    float: left !important;
}
.kv-rtl .pull-left, .kv-rtl .float-left {
    float: right !important;
}
.kv-rtl .kv-zoom-title {
    direction: ltr;
}
.kv-rtl .krajee-default.file-preview-frame {
    box-shadow: -1px 1px 5px 0 #a2958a;
}
.kv-rtl .krajee-default.file-preview-frame:not(.file-preview-error):hover {
    box-shadow: -3px 3px 5px 0 #333;
}
.kv-rtl .kv-zoom-actions .btn-kv {
    margin-left: 0;
    margin-right: 3px;
}
.kv-rtl .file-caption.icon-visible .file-caption-name {
    padding-left: 0;
    padding-right: 15px;
}
.kv-rtl .input-group-btn > .btn:last-child {
    border-radius: 4px 0 0 4px;
}
.kv-rtl .input-group .form-control:first-child {
    border-radius: 0 4px 4px 0;
}
.kv-rtl .btn-file input[type=file] {
    left: auto;
    right: 0;
    text-align: left;
    background: none repeat scroll 100% 0 transparent;
}