{% load i18n %}
<div class="modal fade" id="removeModal" role="dialog"
     aria-labelledby="add_user_modalLabel" aria-hidden="true">
  <div class="modal-dialog">

    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header">
        <h4 class="modal-title">{% trans 'Remove user from team' %}</h4>
        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
      </div>
      <div class="modal-body">
        <p>{% trans 'User "{usr}" will lose access to all projects owned by "{grp}"! Continue?' %}</p>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-bs-dismiss="modal">{% trans 'Cancel' %}</button>
        <button id="removeModalConfirm" type="button" class="btn btn-danger" data-bs-dismiss="modal">{% trans 'Remove' %}</button>
      </div>
    </div>

  </div>
</div>
