a {
  text-decoration: none;
}

hr {
  border: none;
  border-bottom: 1px solid var(--line-context-color);
  margin-bottom: 20px;
}

/* table */
.table {
  margin: 0;
  border-spacing: 0;
}

.table.table-hover tr:hover {
  background-color: rgba(0, 0, 0, 0.025);
}

.table caption {
  padding: 8px;
  text-align: left;
  font-size: 20px;
  letter-spacing: -0.5px;
}

.table caption a {
  color: #333;
}

.table td,
.table th {
  vertical-align: middle;
  padding: 10px;
  font-size: 0.85rem;
  border-bottom: 1px solid #e6e6e6;
}

body .table thead th {
  color: var(--main-color-dark);
  border-top: 0;
  background-color: rgba(0, 0, 0, 0.035);
  border-bottom: 1px solid #e6e6e6;
  vertical-align: middle;
}

.table > :not(:last-child) > :last-child > * {
  border-bottom-color: #e6e6e6;
}

.table tbody tr:first-child th,
.table tbody tr:first-child td {
  border-top: 0;
}

/* forms */
label {
  display: inline-block;
  font-size: 12px;
  font-weight: bold;
  color: #333;
  text-transform: uppercase;
  margin-bottom: 5px;
}

.form-control {
  box-sizing: border-box;
  font-size: 0.9rem;
  margin-bottom: 10px;
  border: 1px solid transparent;
  border-radius: 4px;
  outline: none;
  color: #333;
  border: 1px solid #ddd;
  background-color: #fafafa;
}

textarea.form-control {
  min-height: 100px;
  font-family: inherit;
}

.form-control:focus {
  background-color: white;
  border-color: var(--main-color);
  cursor: text;
  box-shadow: none;
}

.form-control::placeholder {
  opacity: 0.6;
}

.form-control:disabled,
.form-control:disabled:focus {
  color: rgba(0, 0, 0, 0.4);
  background-color: #f2f2f2;
  border: 1px solid #ddd;
}

.form-group textarea {
  width: 100%;
  padding: 5px;
}
