{% extends "vault/base.html" %}

{% block title %}Storage - {{ project_name }}{% endblock %}

{% block content_title %}Object Storage{% endblock %}

{% block content_breadcrumb %}
  <a href="{% url "containerview" project_name %}">Containers</a>
  <span>Create container</span>
{% endblock %}

{% block content %}
  <form method="POST" action="{% url "create_container" project_name %}" class="form-box project-form">
    {% csrf_token %}
    <fieldset class="content">
      <div class="col-md-12">
        <div class="form-group">
          {{ form.containername.label_tag }}
          {{ form.containername }}
          {{ form.containername.errors }}

          <br>
          <span class="help-block">
            Enter name of container here. Use only letters, numbers, underscore or hyphens.<br>
            Please note that you can not rename it afterwards.
          </span>
        </div>

      <div class="col-md-6">&nbsp;</div>
    </fieldset>

    <fieldset class="base">
      <div class="col-md-12">
        <button class="btn btn-primary" type="submit">Create Container</button>
      </div>
    </fieldset>
  </form>
</div>
{% endblock %}
