{% load i18n static %}

<section id="add-user-role" {% if not has_id %}class="disabled"{% endif %}>
  <label>{% trans 'Manage Users:' %}</label>

  <div class="controls">
    <select class="users form-control form-control-sm">
    {% for user in users %}
      <option value="{{ user.id }}">{{ user.name }}</option>
    {% endfor %}
    </select>

    <span>&nbsp;{% trans 'with role:' %}</span>

    <select class="roles form-control form-control-sm">
    {% for role in roles %}
      <option value="{{ role.id }}">{{ role.name }}</option>
    {% endfor %}
    </select>

    <a href="#" class="btn btn-primary btn-sm add-btn">{% trans 'Add' %}</a>
  </div>

  <div class="box-table box-users">
    <table class="table related-users">
      <thead>
        <tr>
          <th width="45%">{% trans 'user' %}</th>
          <th width="45%">{% trans 'role' %}</th>
          <th>&nbsp;</th>
        </tr>
      </thead>
      <tbody></tbody>
    </table>
  </div>

  <div class="lock">
    <span class="msg-lock">{% trans 'Create project to manage users' %}</span>
  </div>
</section>
