{% extends "vault/base_bare.html" %}
{% load i18n static %}

{% block title %}{% trans 'Create Project' %}{% endblock %}

{% block css %}
  <link rel="stylesheet" type="text/css" href="{% static 'identity/css/project.css' %}" />
{% endblock %}

{% block title_left %}{% trans 'Create Project' %}{% endblock %}

{% block content %}
  <form action="" class="form-box project-form" method="POST">
    <input type='hidden' name='csrfmiddlewaretoken' value='{{ csrf_token }}' />
    {{ form.id }}

    <fieldset class="content">

      <div class="row">

        <div class="col-md-12">
          <div class="form-group">
            {{ form.name.label_tag }}
            {{ form.name }}
            {{ form.name.errors }}
          </div>

          <div class="form-group">
            {{ form.description.label_tag }}
            {{ form.description }}
            {{ form.description.errors }}
          </div>

          <div class="form-group">
            {{ form.group.label_tag }}
            {{ form.group }}
            {{ form.group.errors }}
          </div>

          <div class="form-group">
            {{ form.cloud.label_tag }}
            {{ form.cloud }}
            {{ form.cloud.errors }}
          </div>
        </div>

      </div>

    </fieldset>

    <fieldset class="base">
      <div class="col-md-12">
        <button class="btn btn-primary" type="submit">{% trans 'Create Project' %}</button>
      </div>
    </fieldset>
  </form>
{% endblock %}
