#storage-tools {
    position: relative;
    height: 40px;
    margin-bottom: 10px;
    padding: 0 3px;
    border-radius: 2px;
}

#storage-tools .container-name {
    display: inline-block;
    font-size: 20px;
    letter-spacing: -1px;
    color: #666;
    line-height: 30px;
    padding-top: 10px;
}

#storage-tools .container-label {
    position: absolute;
    top: 0;
    left: 3px;
    font-size: 10px;
    text-transform: uppercase;
    color: #aaa;
}

#storage-tools button {
    float: right;
    border: 0;
    margin: 0;
    margin-left: 20px;
    outline: none;
    height: 40px;
    line-height: 40px;
    min-width: 40px;
    font-size: 14px;
    padding: 5px 0 0;
    background-color: transparent;

    color: #888;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}

#storage-tools button:hover {
    color: #333;
}

#storage-tools button .icon {
    margin-right: 6px;
}

#storage-tools button .badge {
    text-shadow: none;
}

.table-content {
    border-bottom: 1px dotted #ccc;
}

#trash-modal .table.blurred {
    filter: blur(1px);
    -webkit-filter: blur(1px);
}

.cell_editing {
    background-color: #FFFACD;
}

.error-msg {
    color: #B22222;
    font-size: 13px;
    display: none;
}

.alert-warning {
    margin: auto;
    font-size: 13px;
    align-items: left;
    text-align:left;
    display: none;
}

.opaque {
    display: none;
    position: absolute;
    top: 0; right: 0; bottom: 0; left: 0;
    background-color: rgba(255, 255, 255, 0.75);
}

.opaque .loader,
.opaque .loader:before,
.opaque .loader:after {
    width: 4px;
    height: 20px;
    background-color: rgba(0, 0, 0, 0.4);
}

.opaque .loader {
    position: absolute;
    top: 50%;
    left: 50%;
    margin-top: -10px;
    margin-left: -2px;
}

.backup-restore-buttons {
    margin-bottom: 15px;
}

.backup-restore-buttons button {
    width: 120px;
    margin-right: 10px;
}

/* SEARCH OBJECTS IN CONTAINERS BOX */
#box_search {
    background-color: #fff;
    border: 1px solid #e2e2e2;
    box-shadow: 0 1px 0 rgba(0,0,0,0.2);
    margin-bottom: 25px;
    height: 110px;
    padding: 15px;

}

#box_query {
    background-color: #fff;
    border: 1px solid #e2e2e2;
    box-shadow: 0 1px 0 rgba(0,0,0,0.2);
    margin-bottom: 40px;
    height: 50px;
    padding: 15px;
}

.finded-term {
    font-family: arial;
    font-weight: bold;
    margin-bottom: 35px;
}

.finded-term span {
    font-weight: bold;
    color:#2b669a;
}

#box_search .send-btn {
    width: 80px;
}

#box_search .search-label {
    margin-left: 15px;
}

#box_search .input-query {
    border: 1px solid #ced4da;
    margin-left: 15px;
    width: 350px;
}

.btn-default {
    cursor: text;
    text-align: left;
}

.btn-primary {
    cursor: auto;
}

.btn {
    cursor: pointer;
}

/* metadata */
.metadata .btn-preview {
    float: right;
}

.metadata .obj-name {
    display: inline-block;
    width: 80%;
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    font-size: 20px;
    font-weight: 300;
    margin-left: 10px;
    color: #52afff;
}

.metadata-items {
    width: 100%;
    list-style: none;
    padding: 0;
    margin: 0;
    margin-top: 20px;
}

.metadata-items .key,
.metadata-items .value {
    display: block;
    font-size: 12px;
    color: #ccc;
}

.metadata-items .key {
    padding: 8px 10px 2px;
    color: #f5ee98;
}

.metadata-items .value {
    padding: 5px 10px;
    background-color: #3e3e3e;
}

.metadata-preview {
    display: none;
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    background-color: rgba(0, 0, 0, 0.1);
}

.metadata-preview.open {
    display: block;
}

.metadata-preview-content {
    position: absolute;
    top: 100px;
    right: 100px;
    bottom: 100px;
    left: 100px;
    border: 1px solid #333;
}

/* container-options */
.container-options-name {
    display: inline-block;
    width: 80%;
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    font-size: 20px;
    font-weight: 300;
    margin-left: 10px;
    color: #52afff;
}

.container-options .container-options-items {
    list-style: none;
    padding: 0;
    margin-top: 20px;
}

.container-options li {
    display: block;
    border-bottom: 1px solid rgba(255, 255, 255, 0.1);
}

.container-options li:last-child {
    border-bottom: none;
}

.container-options li:hover {
    color: white;
    background-color: rgba(255, 255, 255, 0.05);
    cursor: pointer;
}

.container-options li a,
.container-options li a:focus,
.container-options li a:active,
.container-options li a:visited {
    color: #bbb;
    display: block;
    padding: 10px;
    font-size: 14px;
    text-decoration: none;
    outline: none;
}

.container-options li:hover a {
    color: white;
    text-decoration: none;
}

.container-options li a.enabled {
    color: #f5ee98;
}

.config-item .item-enabled,
.config-item .item-disabled { display: none; }
.config-item .item-verifying { display: block; }

.config-item.enabled .item-disabled,
.config-item.enabled .item-verifying { display: none }
.config-item.enabled .item-enabled { display: block; }

.config-item.disabled .item-enabled,
.config-item.disabled .item-verifying { display: none }
.config-item.disabled .item-disabled { display: block; }

.config-item span .icon,
.btn-delete-container span .icon {
    float: right;
    font-size: 16px;
}

.container-options a.btn-delete-container,
.container-options a.btn-delete-container:active,
.container-options a.btn-delete-container:visited {
    color: #e74c3c;
    opacity: 0.75;
}

.container-options a.btn-delete-container:hover {
    color: #e74c3c;
    opacity: 1;
}
