<div class="modal fade" id="addcors_modal" tabindex="-1" role="dialog" aria-labelledby="addcors_modalLabel" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <h5 id="addcors_modalLabel">Add host for container {{ container }}</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true"></button>
      </div>

      <form method="POST" action="{% url 'edit_cors' project=project_name container=container %}" class="form-inl">
        {% csrf_token %}
        <div class="modal-body">
          <label for="host">Host:</label><br />
          <input class="form-control" name="host" type="text">
        </div>
        <div class="modal-footer">
          <button type="submit" class="btn btn-primary">Add Host</button>
          <button class="btn" data-bs-dismiss="modal" aria-hidden="true">Cancel</button>
        </div>
      </form>
    </div>
  </div>
</div>
