{% extends "vault/base.html" %}
{% load i18n static %}

{% block title %}{% trans 'Delete Project' %}{% endblock %}
{% block content_title %}{% trans 'Delete Project' %}{% endblock %}

{% block css %}
  <link rel="stylesheet" type="text/css" href="{% static 'identity/css/project.css' %}" />
{% endblock %}

{% block content %}
  <div class="alert alert-danger">
    <h4 class="alert-heading">{% trans 'Warning!' %}</h4>
    {% blocktrans %}All objects will be deleted. This action is irreversible!{% endblocktrans %}
  </div>

  <form action="" class="form-box project-form" method="POST">
    <input type='hidden' name='csrfmiddlewaretoken' value='{{ csrf_token }}' />
    {{ form.id }}

    <fieldset class="content">
      <div class="row">
        <div class="col-md-12">
          <div class="form-group">
            {{ form.user.label_tag }}
            {{ form.user }}
            {{ form.user.errors }}
          </div>
          <div class="form-group">
            {{ form.password.label_tag }}
            {{ form.password }}
            {{ form.password.errors }}
          </div>
        </div>
      </div>
    </fieldset>

    <fieldset class="base">
      <div class="col-md-12">
        <button class="btn btn-danger" type="submit">{% trans 'Delete Project' %}</button>
      </div>
    </fieldset>
  </form>
{% endblock %}
{% block js_bottom %}
{{ block.super }}
<script>
Base.Forms.init({
  'delete_btn_class': '.delete-user'
});
</script>
{% endblock %}
