<div class="input-group show_hide_password">
  {% include "django/forms/widgets/input.html" %}
  <div class="input-group-text">
    <a href="" class="password-eye"><i class="fa fa-eye-slash" aria-hidden="true"></i></a>
  </div>
</div>
