.login .content-top .logo {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  padding: 100px 0;
}

.login .content-top .logo img {
  width: 25%;
}

.login form {
  width: 100%;
}

.login h3 {
  text-align: center;
  font-weight: lighter;
  color: #777;
  margin: 10px 0 40px;
}

.login .hr-separator {
  position: relative;
  border-top: 1px solid #ccc;
  margin: 30px 0;
  text-align: center;
}

.login .hr-separator::after {
  position: absolute;
  content: "OR";
  width: 50px;
  left: 50%;
  margin-left: -25px;
  font-size: 18px;
  font-weight: lighter;
  line-height: 18px;
  top: -10px;
  background-color: white;
  color: #777;
}

.login .errornote {
  text-align: center;
}
