#add-user-role {
  position: relative;
  margin-bottom: 50px;
}

#add-user-role.disabled {
  opacity: 0.3;
}

#add-user-role.disabled .lock {
  display: block;
}

#add-user-role.disabled .loader-gif {
  display: none;
}

#add-user-role .lock {
  display: none;
  position: absolute;
  top: 0; left: 0; right: 0; bottom: 0;
  z-index: 9;
}

#add-user-role .lock .msg-lock {
  position: absolute;
  bottom: 26px; left: 0; right: 0;
  text-align: center;
  font-size: 20px;
  color: #333;
}

#add-user-role .title {
  margin-bottom: 5px;
}

#add-user-role .controls {
  padding: 0 10px;
  background-color: #ddd;
  border-radius: 5px;
  line-height: 50px;
  min-height: 50px;
  margin-bottom: 25px;
}

#add-user-role .box-users {
  position: relative;
  /* background-color: #eee;
  margin-bottom: 15px;
  border-radius: 5px; */
  min-height: 74px;
  overflow: hidden;
}

#add-user-role .box-users .box-loader {
  display: flex;
  justify-content: center;
  width: 100%;
  height: 100%;
}

#add-user-role .related-users {
  display: none;
}

#add-user-role .related-users li:first-child {
  border-top: none;
}

#add-user-role .users,
#add-user-role .roles {
  width: 28%;
  display: inline-block;
}

#add-user-role .remove-usr {
  float: right;
  font-size: 12px;
}

#add-user-role .dropdown-menu {
  max-height: 280px;
  overflow-y: auto;
}

#add-user-role .add-btn {
  float: right;
  margin-top: 10px;
}

.reset-info {
  display: none;
  padding: 6px 12px;
  font-size: 14px;
  vertical-align: middle;
  margin-left: 10px;
  background-color: #FCF8E3;
  box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.2);
}

.reset-info.visible {
  display: inline-block;
}

.reset-info .new-pass {
  font-weight: bold;
}

#project-metadata {
  margin-bottom: 30px;
}

#project-metadata h4 {
  margin: 0 0 20px;
}

#project-metadata .t-info {
  width: 100%;
}

#project-metadata .t-info th {
  width: 30%;
  text-align: right;
}

.credentials h4 {
  margin-bottom: 40px;
}

.credentials table th {
  text-align: right;
}

.service-name {
  border-radius: 3px;
  padding: 2px 8px;
  color: white;
  background-color: grey;
}

.service-name.vault {
  background-color: dodgerblue;
}

.change-project-list {
  min-height: 300px;
}

.create-project-btn {
  padding: 15px 30px;
  font-weight: normal;
  font-size: 16px;
  white-space: nowrap;
  text-align: center;
  background-color: white;
  color: #333;
  opacity: .85;
  border-radius: 5px;
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
}

.create-project-btn:hover {
  text-decoration: none;
  color: #333;
  opacity: 1;
}

.create-project-btn .icon {
  display: inline-block;
  margin-right: 10px;
}

.no-team .no-team-title {
  font-weight: lighter;
  color: #333;
  margin-bottom: 30px;
}

.no-team .no-team-msg {
  margin-bottom: 30px;
}

.no-team .no-team-options {
  margin: 20px 0 0;
}

.no-team .no-team-options li {
  margin: 10px 0 0;
}

.no-team .icon-warning {
  position: absolute;
  font-size: 130px;
  bottom: 30px;
  right: 30px;
  color: rgba(0, 0, 0, 0.1);
}
