{% extends "vault/base_bare.html" %}
{% load i18n static %}

{% block title %}{% trans 'Error' %}{% endblock %}

{% block main_content %}
<div class="container-fluid">
  <div class="row">
    <div class="col-md-12">
      
      <div class="vault-error">
        <h1>Error</h1>
        <h2>{% trans '500, Something went wrong...' %}</h2>
      </div>
    
    </div>
  </div>
</div>
{% endblock %}
