.dashboard-widgets {
  list-style: none;
  padding: 0;
}

.dashboard-info {
  padding: 30px;
}

.dashboard-info .useful-links {
  margin-bottom: 30px;
}

.dashboard-info h4 {
  font-size: 18px;
  font-weight: normal;
  color: #333;
}

.dashboard-info span {
  font-size: 14px;
  color: #777;
}

.useful-links .item {
  display: flex;
  align-items: center;
  padding: 5px;
  border-radius: 4px;
  color: #777;
  margin-bottom: 20px;
  background-color: #f8f8f8;
}

.useful-links .item.highlighted {
  color: #664d03;
  background-color: #fff3cd;
}

.useful-links .item:hover {
  text-decoration: none;
  color: #333;
  background-color: rgba(0, 0, 0, 0.1);
}

.useful-links .item:hover .text {
  color: #333;
}

.useful-links .item .icon {
  font-size: 32px;
  width: 40px;
  margin: 0 15px 0 5px;
}

.useful-links .item .text {
  flex-grow: 1;
}

.useful-links .item-title {
  display: block;
  text-transform: uppercase;
  font-size: 12px;
  font-weight: bold;
}

.useful-links .item-text {
  font-size: 12px;
}

.widget {
  box-sizing: border-box;
  padding-top: 120px;
  padding-bottom: 60px;
  position: relative;
  margin-bottom: 30px;
  min-height: 400px;
}

.widget .head {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 165px;
  padding: 30px;
  color: white;
  background-color: #999;
  border-radius: 4px 4px 0 0;
}

.extra-info {
  position: absolute;
  top: 30px;
  right: 30px;
  font-size: 1.2rem;
  color: white;
}

.extra-info:hover {
  color: white;
  opacity: 0.8;
}

.extra-info .status {
  font-size: 16px;
  font-weight: 300;
  display: inline-block;
  letter-spacing: -0.02em;
}

.widget .name {
  font-size: 16px;
  font-weight: 300;
  display: inline-block;
}

.widget .info {
  font-size: 30px;
  font-size: 1.8em;
  display: block;
}

.widget .base {
  position: absolute;
  bottom: 0;
  left: 0;
  padding: 10px 30px 30px;
  text-align: right;
  width: 100%;
}

.widget .base .btn {
  margin-left: 5px;
}

.widget.content table {
  margin: 0;
}

.widget.content table th {
  width: 10%;
  text-align: right;
}

.widget.content table input {
  border-color: #eee;
  border-radius: 0;
}

.widget .big-number {
  display: block;
  font-size: 26px;
  font-weight: lighter;
  line-height: 32px;
}

.widget .content {
  position: relative;
  display: flex;
  flex-flow: row wrap;
  flex-direction: row;
  align-items: center;
  justify-content: center;
  margin: 0 -10px;
}

.widget .content .item-box {
  display: flex;
  flex: 1 1 0px;
  flex-flow: column;
  justify-content: center;
  padding: 15px 10px;
  font-weight: 300;
  font-size: 16px;
  text-align: center;
  margin: 0 10px 20px;
  background-color: white;
  color: #333;
  border-radius: 10px;
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.15);
}

.widget .content .item-box-break {
  flex-basis: 100%;
  height: 0;
}

.widget-dummy {
  min-height: 400px;
  border-radius: 4px;
  opacity: 0.75;
  animation-name: widget-pulse;
  animation-duration: 1.2s;
  animation-iteration-count: infinite;
}

@keyframes widget-pulse {
  from {
    background-color: #eee;
  }
  50% {
    background-color: #dfdfdf;
  }
  to {
    background-color: #eee;
  }
}
